==> arts-2023.11.5.tar.gz: arts-2023.11.5/arts/static/articles/011-万象思考/061-堕胎自由权/README.md <==
> 2022年6月24日美国最高法院裁决推翻“罗诉韦德案”。1973年此案裁决使堕胎在美国合法化。
> 据《华尔街日报》报道，美国最高法院24日裁定，取消宪法规定的堕胎权，推翻1973年“罗伊诉韦德案”的裁决，并将堕胎的合法性问题留给了各州应对。这一裁决颠覆了近50年前具有里程碑意义的先例，是一个罕见的逆转，挑战现代美国的生殖自主权。

# 堕胎即杀人

一个亿万富翁要去谈一笔生意，张三故意把他的车轮搞坏，导致车子半路抛锚，最终导致这个富翁损失了 1 亿元。

显然，法官不会判处张三仅仅赔偿一个轮胎的钱，而会判处他同时赔偿富翁在生意上的损失。原因在于：损坏了轮胎，也就损坏了富翁的“尚未兑现但已确定无疑”的财产。

再比如，一张中奖的彩票，就是一笔“尚未兑现但已确定无疑”的财产。

**胎儿不论是否已出生、是否已成为一名公民、是否已具有自主意识，都不影响 Ta 具有发生“降生→成长→衰老→死亡”这一完整人生过程的能力，而这一过程恰恰是人生的内涵，“人生”则是这一过程的高度概括。杀死一个胎儿，就是杀死了一场完整的人生，也即杀死了这样一个原本应该存在于未来的人。**

# 法律的本质

法律并不是 [无差别] 的公平公正，而是 [针对特定人群] 的公平公正。

法律的本质是“利益协议”，是丛林法则的产物。**在有 [相互利害关系] 且 [势均力敌] 的群体中，为了避免两败俱伤的局面，达成“利益协议”，这便是法律。**

只有势均力敌、存在相互利害关系的人之间，才有谈规则、定法律的基础。

# 弱者无权

规则是强者之间商讨制定的，所谓生命权，也是规则赋予的，而非天生的。

人类只对人类赋予生命权，不会对动物赋予生命权。动物会被做成口中的餐，因为动物没有与人对抗的资格（武力）。

# 胎儿为弱者，无权

胎儿由于不具备任何影响社会、影响人类的主观能力，因此 Ta 对于成人只存“利”，不存“害”，构不成 [相互利害关系] ，且与成人相比处于绝对弱势的处境，构不成 [势均力敌] 。

胎儿与成人力量差距悬殊，达不到与成人谈规则的资格，因此不具有生命权，其生杀权掌握在强者（成人）手上。

# 承认我们的血腥与凶残

如果我们只谈保护人的生命权，不谈保护动物的生命权，本质上就仍然是丛林法则。

不论你自称“支持”还是“反对”堕胎自由，有一个事实是：我们几乎每天都在吃肉。**我们早已用行动承认、践行、内化了丛林法则。**

既然如此，我们不妨大大方方地承认：我们践行的是丛林法则，胎儿是弱者，没有资格与已出生的人（强者）谈生命权。

# 胎儿生命权的局部最优解

很多时候，我们无法达到“全局最优解”，但不应该破罐子破摔，而应尽量做好“局部最优解”。

我们做不到不吃肉，无法践行真正的“众生平等”，这使我们无法达到全局最优解，但胎儿是生活的一个局部，在处理这个局部的时候，我们应该寻找局部最优解。

如果胎儿的生命权与成人的权利没有冲突，则我（几乎所有人）都会坚决维护胎儿的生命权，反对堕胎自由。

但事实是这个冲突就是存在。法律不就是保护我们（已入局的)大家吗？如果法律不保护已入局的成人，而是去保护尚未入局的胎儿，法律也就违背了它的初衷，“利益同盟”也将趋向瓦解。

就好比两国打仗，敌国是敌国的局，我国是我国的局，难道因为对方是个人，我们的士兵就不开枪吗？当胎儿与成人的权利相冲突时，其实也是一样的道理。

那么，有没有什么办法能既保护胎儿，且不影响成人的权利？答案是“科技”。

老话说：“求同存异”。并不是所有的问题都要去直面的，发展科学的目的本就是使人的生活过得更好，有些棘手的问题如果能用技术解决是再好不过了。

相信在不远的将来，可以实现这样一个政策：成人决定堕胎的情况下，将胎儿通过技术转移到培养舱，后续由政府接管进行胎儿的抚养。手续办完后，消除胎儿与父母之间的一切资料，从技术上确保消除不可逆，从此胎儿与父母再无任何交集。

# 后记

我们每个人都是构成丛林法则的一份子，都是凶残、血腥的，而承认这一点，似乎对大部分人来说都很难，我们习惯于放大自己阳光的一面，而逃避阴暗的一面，以至于发明了很多自欺欺人的宏观大道理，如：“动物的宿命就是让人吃”，并且也虚伪地谈“胎儿的生命权”。

==> arts-2023.11.17.tar.gz: arts-2023.11.17/arts/static/articles/011-万象思考/061-堕胎自由权/README.md <==
> 2022年6月24日美国最高法院裁决推翻“罗诉韦德案”。1973年此案裁决使堕胎在美国合法化。
> 据《华尔街日报》报道，美国最高法院24日裁定，取消宪法规定的堕胎权，推翻1973年“罗伊诉韦德案”的裁决，并将堕胎的合法性问题留给了各州应对。这一裁决颠覆了近50年前具有里程碑意义的先例，是一个罕见的逆转，挑战现代美国的生殖自主权。

# 堕胎即杀人

一个亿万富翁要去谈一笔生意，张三故意把他的车轮搞坏，导致车子半路抛锚，最终导致这个富翁损失了 1 亿元。

显然，法官不会判处张三仅仅赔偿一个轮胎的钱，而会判处他同时赔偿富翁在生意上的损失。原因在于：损坏了轮胎，也就损坏了富翁的“尚未兑现但已确定无疑”的财产。

再比如，一张中奖的彩票，就是一笔“尚未兑现但已确定无疑”的财产。

**胎儿不论是否已出生、是否已成为一名公民、是否已具有自主意识，都不影响 Ta 具有发生“降生→成长→衰老→死亡”这一完整人生过程的能力，而这一过程恰恰是人生的内涵，“人生”则是这一过程的高度概括。杀死一个胎儿，就是杀死了一场完整的人生，也即杀死了这样一个原本应该存在于未来的人。**

# 法律的本质

法律并不是 [无差别] 的公平公正，而是 [针对特定人群] 的公平公正。

法律的本质是“利益协议”，是丛林法则的产物。**在有 [相互利害关系] 且 [势均力敌] 的群体中，为了避免两败俱伤的局面，达成“利益协议”，这便是法律。**

只有势均力敌、存在相互利害关系的人之间，才有谈规则、定法律的基础。

# 弱者无权

规则是强者之间商讨制定的，所谓生命权，也是规则赋予的，而非天生的。

人类只对人类赋予生命权，不会对动物赋予生命权。动物会被做成口中的餐，因为动物没有与人对抗的武力。

# 胎儿为弱者，无权

胎儿由于不具备任何影响社会和人类的主观能力，因此 Ta 对于成人只存“利”，不存“害”，构不成 [相互利害关系] ，且与成人相比属于绝对弱势，构不成 [势均力敌] 。

胎儿与成人力量差距悬殊，达不到与成人谈规则的资格，因此不具有生命权，其生杀权掌握在强者（成人）手上。

# 承认我们的血腥与凶残

如果我们只谈保护人的生命权，不谈保护动物的生命权，本质上就仍然是丛林法则。

不论你自称“支持”还是“反对”堕胎自由，有一个事实是：我们几乎每天都在吃肉。**我们早已用行动承认、践行、内化了丛林法则。**

既然如此，我们不妨大大方方地承认：我们践行的是丛林法则，胎儿是弱者，没有资格与已出生的人（强者）谈生命权。

# 胎儿生命权的局部最优解

很多时候，我们无法达到“全局最优解”，但不应该破罐子破摔，而应尽量做好“局部最优解”。

我们做不到不吃肉，无法践行真正的“众生平等”，这使我们无法达到全局最优解，但胎儿是生活的一个局部，在处理这个局部的时候，我们应该寻找局部最优解。

如果胎儿的生命权与成人的权利没有冲突，则我（几乎所有人）都会坚决维护胎儿的生命权，反对堕胎自由。

但事实是这个冲突就是存在。法律不就是保护我们（已入局的)大家吗？如果法律不保护已入局的成人，而是去保护尚未入局的胎儿，法律也就违背了它的初衷，“利益同盟”也将趋向瓦解。

就好比两国打仗，敌国是敌国的局，我国是我国的局，难道因为对方是个人，我们的士兵就不开枪吗？当胎儿与成人的权利相冲突时，其实也是一样的道理。

那么，有没有什么办法能既保护胎儿，且不影响成人的权利？答案是“科技”。

老话说：“求同存异”。并不是所有的问题都要去直面的，发展科学的目的本就是使人的生活过得更好，有些棘手的问题如果能用技术解决是再好不过了。

相信在不远的将来，可以实现这样一个政策：成人决定堕胎的情况下，将胎儿通过技术转移到培养舱，后续由政府接管进行胎儿的抚养。手续办完后，消除胎儿与父母之间的一切资料，从技术上确保消除不可逆，从此胎儿与父母再无任何交集。

# 后记

我们每个人都是构成丛林法则的一份子，都是凶残、血腥的，而承认这一点，似乎对大部分人来说都很难，我们习惯于放大自己阳光的一面，而逃避阴暗的一面，以至于发明了很多自欺欺人的宏观大道理，如：“动物的宿命就是让人吃”，并且也虚伪地谈“胎儿的生命权”。
